@@ -1,10 +1,10 @@
 from .errors import BadFileTypeError, SchemaParseError, UnsupportedUrlScheme
-from .instance import InstanceLoader, instance_loader_from_args
+from .instance import InstanceLoader
 from .schema import (
     BuiltinSchemaLoader,
+    MetaSchemaLoader,
     SchemaLoader,
     SchemaLoaderBase,
-    schema_loader_from_args,
 )
 
 __all__ = (
@@ -12,9 +12,8 @@ __all__ = (
     "SchemaParseError",
     "UnsupportedUrlScheme",
     "BuiltinSchemaLoader",
+    "MetaSchemaLoader",
     "SchemaLoader",
     "SchemaLoaderBase",
     "InstanceLoader",
-    "schema_loader_from_args",
-    "instance_loader_from_args",
 )
