@@ -4,6 +4,12 @@ import ruamel.yaml
 
 _yaml = ruamel.yaml.YAML(typ="safe")
 
+# ruamel.yaml parses timestamp values into datetime.datetime values which differs from
+# JSON which parses timestamps as strings. Turn off this feature.
+_yaml.constructor.yaml_constructors[
+    "tag:yaml.org,2002:timestamp"
+] = _yaml.constructor.yaml_constructors["tag:yaml.org,2002:str"]
+
 
 def _normalize(data: t.Any) -> t.Any:
     """
